@@ -5,7 +5,7 @@ Do not add this file to the repository.
 
 """
 
-__version__ = '1.0'
+__version__ = '1.1'
 __revision__ = None
-__date__ = 'Sun Aug  1 07:58:06 2010'
+__date__ = 'Sat May 14 12:12:14 2011'
 
